==> attal_0.9.1.orig.tar.gz: attal-0.9.1/themeEditor/decorationEffect.cpp <==
/****************************************************************
**
** Attal : Lords of Doom
**
** decorationEfefct.cpp
** Widget for editing effects of decoration
**
** Version : $Id: decorationEffect.cpp,v 1.4 2004/03/07 20:45:57 audoux Exp $
**
** Author(s) : Pascal Audoux
**
** Date : 15/08/2003
**
** Licence :
**	This program is free software; you can redistribute it and/or modify
**   	it under the terms of the GNU General Public License as published by
**     	the Free Software Foundation; either version 2, or (at your option)
**      any later version.
**
**	This program is distributed in the hope that it will be useful,
** 	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
**
****************************************************************/

#include "decorationEffect.h"

// generic include files
// include files for QT
#include <qcombobox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qspinbox.h>
// application specific include files
#include "libCommon/genericDecoration.h"
#include "libCommon/log.h"

#include "libClient/gui.h"


//
// ----- DecorationEffect -----
//

DecorationEffect::DecorationEffect( QWidget * parent, const char * name )
: QWidget( parent, name )
{
	_deco = 0;
	_listBox = new QListBox( this );

	_pbAdd = new QPushButton( this );
	_pbAdd->setText( tr( "Add" ) );
	FIXEDSIZE( _pbAdd );

	_pbEdit = new QPushButton( this );
	_pbEdit->setText( tr( "Edit" ) );
	FIXEDSIZE( _pbEdit );

	_pbDel = new QPushButton( this );
	_pbDel->setText( tr( "Del" ) );
	FIXEDSIZE( _pbDel );

	QGridLayout * layout = new QGridLayout( this, 4, 2 );
	layout->setRowStretch( 3, 1 );
	layout->setColStretch( 0, 1 );
	layout->addMultiCellWidget( _listBox, 0, 3, 0, 0 );
	layout->addWidget( _pbAdd, 0, 1 );
	layout->addWidget( _pbEdit, 1, 1 );
	layout->addWidget( _pbDel, 2, 1 );

	layout->activate();

	connect( _pbAdd, SIGNAL( clicked() ), SLOT( slot_add() ) );
	connect( _pbEdit, SIGNAL( clicked() ), SLOT( slot_edit() ) );
	connect( _pbDel, SIGNAL( clicked() ), SLOT( slot_del() ) );
}

void DecorationEffect::init( GenericDecoration * decoration )
{
	_deco = decoration;

	_listBox->clear();
	if( decoration ) {
		uint nb = decoration->getEffectNumber();

		for( uint i = 0; i < nb; ++i ) {
			GenericDecoration::EffectType type = _deco->getEffectType( i );
			uint param = _deco->getEffectParam( i );

			_listBox->insertItem( new EffectItem( type, param ) );
		}
	}
}

void DecorationEffect::slot_add()
{
	DialogEffect dialog;

	if( dialog.exec() ) {
		GenericDecoration::EffectType type = dialog.getType();
		uint param = dialog.getParam();
		_listBox->insertItem( new EffectItem( type, param ) );
	}
}

void DecorationEffect::slot_edit()
{
	int item = _listBox->currentItem();
	if( item != -1 ) {
		DialogEffect dialog;
		dialog.setType( ( (EffectItem*)(_listBox->item( item ) ) )->getType() );
		dialog.setParam( ( (EffectItem*)(_listBox->item( item ) ) )->getParam() );
		if( dialog.exec() ) {
			GenericDecoration::EffectType type = dialog.getType();
			uint param = dialog.getParam();
			EffectItem * effect = (EffectItem*) _listBox->item( item );
			effect->setType( type );
			effect->setParam( param );
		}
	}
}

void DecorationEffect::slot_del()
{
	int item = _listBox->currentItem();
	if( item != -1 ) {
		_listBox->removeItem( item );
	}
}

void DecorationEffect::save()
{
	_deco->clearEffects();
	uint nb = _listBox->count();
	for( uint i = 0; i < nb; ++i ) {
		EffectItem * effect = (EffectItem*) _listBox->item( i );
		if( effect->getType() != GenericDecoration::NONE ) {
			_deco->addEffect( effect->getType(), effect->getParam() );
		}
	}
}

//
// ----- EffectItem -----
//

EffectItem::EffectItem( GenericDecoration::EffectType type, uint param )
: QListBoxText()
{
	_param = param;
	_type = type;
	computeLabel();
}

void EffectItem::computeLabel()
{
	QString text = QObject::tr( "Effect '" );
	text += GenericDecoration::getEffectTypeString( _type );
	text += QObject::tr( "' with param " );
	text += QString::number( _param );
	setText( text );
}


//
// ----- DialogEffect -----
//

DialogEffect::DialogEffect( QWidget * parent, const char * name )
: QDialog( parent, name, true )
{
	QLabel * labType = new QLabel( tr( "Effect type: " ), this );
	FIXEDSIZE( labType );

	_combo = new QComboBox( this );
	_combo->insertItem( GenericDecoration::getEffectTypeString( GenericDecoration::NONE ) );
	_combo->insertItem( GenericDecoration::getEffectTypeString( GenericDecoration::NO_MOVE ) );
	_combo->insertItem( GenericDecoration::getEffectTypeString( GenericDecoration::DECREASE_MOVECOST ) );
	_combo->insertItem( GenericDecoration::getEffectTypeString( GenericDecoration::INCREASE_MOVECOST ) );
	_combo->insertItem( GenericDecoration::getEffectTypeString( GenericDecoration::NO_TECHNICAL ) );
	_combo->insertItem( GenericDecoration::getEffectTypeString( GenericDecoration::MAX_TECHNICAL ) );
	FIXEDSIZE( _combo );

	QLabel * labParam = new QLabel( tr( "Effect value: " ), this );
	FIXEDSIZE( labParam );

	_spin = new QSpinBox( this );
	_spin->setMinValue( 0 );

	QGridLayout * grid = new QGridLayout( 2, 4 );
	grid->addWidget( labType, 1, 0 );
	grid->addWidget( labParam, 2, 0 );
	grid->addWidget( _combo, 1, 1 );
	grid->addWidget( _spin, 2, 1 );
	grid->addColSpacing( 0, 5 );
	grid->addColSpacing( 3, 5 );

	QPushButton * pbOk = new QPushButton( this );
	pbOk->setText( tr( "Ok" ) );
	FIXEDSIZE( pbOk );

	QPushButton * pbCan = new QPushButton( this );
	pbCan->setText( tr( "Cancel" ) );
	FIXEDSIZE( pbCan );

	QHBoxLayout * layH1 = new QHBoxLayout();
	layH1->addStretch( 1 );
	layH1->addWidget( pbOk );
	layH1->addStretch( 1 );
	layH1->addWidget( pbCan );
	layH1->addStretch( 1 );

	QVBoxLayout * layout = new QVBoxLayout( this );
	layout->setSpacing( 5 );
	layout->setMargin( 5 );
	layout->addLayout( grid, 1 );
	layout->addLayout( layH1 );
	layout->activate();

	connect( pbOk, SIGNAL( clicked() ), SLOT( accept() ) );
	connect( pbCan, SIGNAL( clicked() ), SLOT( reject() ) );
	FIXEDSIZE( this );
}

void DialogEffect::updateDialog()
{
	_spin->setValue( _param );
	_combo->setCurrentItem( (int)_type );
}

void DialogEffect::accept()
{
	_param = _spin->value();
	_type = (GenericDecoration::EffectType) _combo->currentItem();
	QDialog::accept();
}

==> attal_0.9.2.orig.tar.gz: attal-0.9.2/themeEditor/decorationEffect.cpp <==
/****************************************************************
**
** Attal : Lords of Doom
**
** decorationEfefct.cpp
** Widget for editing effects of decoration
**
** Version : $Id: decorationEffect.cpp,v 1.5 2004/12/18 12:21:05 audoux Exp $
**
** Author(s) : Pascal Audoux
**
** Date : 15/08/2003
**
** Licence :
**	This program is free software; you can redistribute it and/or modify
**   	it under the terms of the GNU General Public License as published by
**     	the Free Software Foundation; either version 2, or (at your option)
**      any later version.
**
**	This program is distributed in the hope that it will be useful,
** 	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
**
****************************************************************/

#include "decorationEffect.h"

// generic include files
// include files for QT
#include <qcombobox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qspinbox.h>
// application specific include files
#include "libCommon/genericDecoration.h"
#include "libCommon/log.h"

#include "libClient/gui.h"


//
// ----- DecorationEffect -----
//

DecorationEffect::DecorationEffect( QWidget * parent, const char * name )
: QWidget( parent, name )
{
	_group = 0;
	_listBox = new QListBox( this );

	_pbAdd = new QPushButton( this );
	_pbAdd->setText( tr( "Add" ) );
	FIXEDSIZE( _pbAdd );

	_pbEdit = new QPushButton( this );
	_pbEdit->setText( tr( "Edit" ) );
	FIXEDSIZE( _pbEdit );

	_pbDel = new QPushButton( this );
	_pbDel->setText( tr( "Del" ) );
	FIXEDSIZE( _pbDel );

	QGridLayout * layout = new QGridLayout( this, 4, 2 );
	layout->setRowStretch( 3, 1 );
	layout->setColStretch( 0, 1 );
	layout->addMultiCellWidget( _listBox, 0, 3, 0, 0 );
	layout->addWidget( _pbAdd, 0, 1 );
	layout->addWidget( _pbEdit, 1, 1 );
	layout->addWidget( _pbDel, 2, 1 );

	layout->activate();

	connect( _pbAdd, SIGNAL( clicked() ), SLOT( slot_add() ) );
	connect( _pbEdit, SIGNAL( clicked() ), SLOT( slot_edit() ) );
	connect( _pbDel, SIGNAL( clicked() ), SLOT( slot_del() ) );
}

void DecorationEffect::init( DecorationGroup * group )
{
	_group = group;

	_listBox->clear();
	if( _group ) {
		uint nb = _group->getEffectNumber();

		for( uint i = 0; i < nb; ++i ) {
			DecorationGroup::EffectType type = _group->getEffectType( i );
			uint param = _group->getEffectParam( i );

			_listBox->insertItem( new EffectItem( type, param ) );
		}
	}
}

void DecorationEffect::slot_add()
{
	DialogEffect dialog;

	if( dialog.exec() ) {
		DecorationGroup::EffectType type = dialog.getType();
		uint param = dialog.getParam();
		_listBox->insertItem( new EffectItem( type, param ) );
	}
}

void DecorationEffect::slot_edit()
{
	int item = _listBox->currentItem();
	if( item != -1 ) {
		DialogEffect dialog;
		dialog.setType( ( (EffectItem*)(_listBox->item( item ) ) )->getType() );
		dialog.setParam( ( (EffectItem*)(_listBox->item( item ) ) )->getParam() );
		if( dialog.exec() ) {
			DecorationGroup::EffectType type = dialog.getType();
			uint param = dialog.getParam();
			EffectItem * effect = (EffectItem*) _listBox->item( item );
			effect->setType( type );
			effect->setParam( param );
		}
	}
}

void DecorationEffect::slot_del()
{
	int item = _listBox->currentItem();
	if( item != -1 ) {
		_listBox->removeItem( item );
	}
}

void DecorationEffect::save()
{
	_group->clearEffects();
	uint nb = _listBox->count();
	for( uint i = 0; i < nb; ++i ) {
		EffectItem * effect = (EffectItem*) _listBox->item( i );
		if( effect->getType() != DecorationGroup::NONE ) {
			_group->addEffect( effect->getType(), effect->getParam() );
		}
	}
}

//
// ----- EffectItem -----
//

EffectItem::EffectItem( DecorationGroup::EffectType type, uint param )
: QListBoxText()
{
	_param = param;
	_type = type;
	computeLabel();
}

void EffectItem::computeLabel()
{
	QString text = QObject::tr( "Effect '" );
	text += DecorationGroup::getEffectTypeString( _type );
	text += QObject::tr( "' with param " );
	text += QString::number( _param );
	setText( text );
}


//
// ----- DialogEffect -----
//

DialogEffect::DialogEffect( QWidget * parent, const char * name )
: QDialog( parent, name, true )
{
	QLabel * labType = new QLabel( tr( "Effect type: " ), this );
	FIXEDSIZE( labType );

	_combo = new QComboBox( this );
	_combo->insertItem( DecorationGroup::getEffectTypeString( DecorationGroup::NONE ) );
	_combo->insertItem( DecorationGroup::getEffectTypeString( DecorationGroup::NO_MOVE ) );
	_combo->insertItem( DecorationGroup::getEffectTypeString( DecorationGroup::DECREASE_MOVECOST ) );
	_combo->insertItem( DecorationGroup::getEffectTypeString( DecorationGroup::INCREASE_MOVECOST ) );
	_combo->insertItem( DecorationGroup::getEffectTypeString( DecorationGroup::NO_TECHNICAL ) );
	_combo->insertItem( DecorationGroup::getEffectTypeString( DecorationGroup::MAX_TECHNICAL ) );
	FIXEDSIZE( _combo );

	QLabel * labParam = new QLabel( tr( "Effect value: " ), this );
	FIXEDSIZE( labParam );

	_spin = new QSpinBox( this );
	_spin->setMinValue( 0 );

	QGridLayout * grid = new QGridLayout( 2, 4 );
	grid->addWidget( labType, 1, 0 );
	grid->addWidget( labParam, 2, 0 );
	grid->addWidget( _combo, 1, 1 );
	grid->addWidget( _spin, 2, 1 );
	grid->addColSpacing( 0, 5 );
	grid->addColSpacing( 3, 5 );

	QPushButton * pbOk = new QPushButton( this );
	pbOk->setText( tr( "Ok" ) );
	FIXEDSIZE( pbOk );

	QPushButton * pbCan = new QPushButton( this );
	pbCan->setText( tr( "Cancel" ) );
	FIXEDSIZE( pbCan );

	QHBoxLayout * layH1 = new QHBoxLayout();
	layH1->addStretch( 1 );
	layH1->addWidget( pbOk );
	layH1->addStretch( 1 );
	layH1->addWidget( pbCan );
	layH1->addStretch( 1 );

	QVBoxLayout * layout = new QVBoxLayout( this );
	layout->setSpacing( 5 );
	layout->setMargin( 5 );
	layout->addLayout( grid, 1 );
	layout->addLayout( layH1 );
	layout->activate();

	connect( pbOk, SIGNAL( clicked() ), SLOT( accept() ) );
	connect( pbCan, SIGNAL( clicked() ), SLOT( reject() ) );
	FIXEDSIZE( this );
}

void DialogEffect::updateDialog()
{
	_spin->setValue( _param );
	_combo->setCurrentItem( (int)_type );
}

void DialogEffect::accept()
{
	_param = _spin->value();
	_type = (DecorationGroup::EffectType) _combo->currentItem();
	QDialog::accept();
}
